@@ -20,8 +20,6 @@
 
 import re
 
-from future.utils import string_types
-
 from telegram import Update
 from .handler import Handler
 
@@ -105,14 +103,14 @@ class CallbackQueryHandler(Handler):
                  pass_groupdict=False,
                  pass_user_data=False,
                  pass_chat_data=False):
-        super(CallbackQueryHandler, self).__init__(
+        super().__init__(
             callback,
             pass_update_queue=pass_update_queue,
             pass_job_queue=pass_job_queue,
             pass_user_data=pass_user_data,
             pass_chat_data=pass_chat_data)
 
-        if isinstance(pattern, string_types):
+        if isinstance(pattern, str):
             pattern = re.compile(pattern)
 
         self.pattern = pattern
@@ -139,9 +137,7 @@ class CallbackQueryHandler(Handler):
                 return True
 
     def collect_optional_args(self, dispatcher, update=None, check_result=None):
-        optional_args = super(CallbackQueryHandler, self).collect_optional_args(dispatcher,
-                                                                                update,
-                                                                                check_result)
+        optional_args = super().collect_optional_args(dispatcher, update, check_result)
         if self.pattern:
             if self.pass_groups:
                 optional_args['groups'] = check_result.groups()
