@@ -25,17 +25,18 @@ from telegram import User, Message
 
 @pytest.fixture(scope='class')
 def chat(bot):
-    return Chat(TestChat.id, TestChat.title, TestChat.type, username=TestChat.username,
+    return Chat(TestChat.id_, TestChat.title, TestChat.type_, username=TestChat.username,
                 all_members_are_administrators=TestChat.all_members_are_administrators,
                 bot=bot, sticker_set_name=TestChat.sticker_set_name,
                 can_set_sticker_set=TestChat.can_set_sticker_set,
-                permissions=TestChat.permissions)
+                permissions=TestChat.permissions,
+                slow_mode_delay=TestChat.slow_mode_delay)
 
 
-class TestChat(object):
-    id = -28767330
+class TestChat:
+    id_ = -28767330
     title = 'ToledosPalaceBot - Group'
-    type = 'group'
+    type_ = 'group'
     username = 'username'
     all_members_are_administrators = False
     sticker_set_name = 'stickers'
@@ -45,33 +46,36 @@ class TestChat(object):
         can_change_info=False,
         can_invite_users=True,
     )
+    slow_mode_delay = 30
 
     def test_de_json(self, bot):
         json_dict = {
-            'id': self.id,
+            'id': self.id_,
             'title': self.title,
-            'type': self.type,
+            'type': self.type_,
             'username': self.username,
             'all_members_are_administrators': self.all_members_are_administrators,
             'sticker_set_name': self.sticker_set_name,
             'can_set_sticker_set': self.can_set_sticker_set,
-            'permissions': self.permissions.to_dict()
+            'permissions': self.permissions.to_dict(),
+            'slow_mode_delay': self.slow_mode_delay
         }
         chat = Chat.de_json(json_dict, bot)
 
-        assert chat.id == self.id
+        assert chat.id == self.id_
         assert chat.title == self.title
-        assert chat.type == self.type
+        assert chat.type == self.type_
         assert chat.username == self.username
         assert chat.all_members_are_administrators == self.all_members_are_administrators
         assert chat.sticker_set_name == self.sticker_set_name
         assert chat.can_set_sticker_set == self.can_set_sticker_set
         assert chat.permissions == self.permissions
+        assert chat.slow_mode_delay == self.slow_mode_delay
 
     def test_de_json_default_quote(self, bot):
         json_dict = {
-            'id': self.id,
-            'type': self.type,
+            'id': self.id_,
+            'type': self.type_,
             'pinned_message': Message(
                 message_id=123,
                 from_user=None,
@@ -94,6 +98,7 @@ class TestChat(object):
         assert chat_dict['username'] == chat.username
         assert chat_dict['all_members_are_administrators'] == chat.all_members_are_administrators
         assert chat_dict['permissions'] == chat.permissions.to_dict()
+        assert chat_dict['slow_mode_delay'] == chat.slow_mode_delay
 
     def test_link(self, chat):
         assert chat.link == 'https://t.me/{}'.format(chat.username)
@@ -102,9 +107,9 @@ class TestChat(object):
 
     def test_send_action(self, monkeypatch, chat):
         def test(*args, **kwargs):
-            id = args[0] == chat.id
+            id_ = args[0] == chat.id
             action = kwargs['action'] == ChatAction.TYPING
-            return id and action
+            return id_ and action
 
         monkeypatch.setattr(chat.bot, 'send_chat_action', test)
         assert chat.send_action(action=ChatAction.TYPING)
@@ -167,6 +172,16 @@ class TestChat(object):
         monkeypatch.setattr(chat.bot, 'set_chat_permissions', test)
         assert chat.set_permissions(self.permissions)
 
+    def test_set_administrator_custom_title(self, monkeypatch, chat):
+        def test(*args, **kwargs):
+            chat_id = args[1] == chat.id
+            user_id = args[2] == 42
+            custom_title = args[3] == 'custom_title'
+            return chat_id and user_id and custom_title
+
+        monkeypatch.setattr('telegram.Bot.set_chat_administrator_custom_title', test)
+        assert chat.set_administrator_custom_title(42, 'custom_title')
+
     def test_instance_method_send_message(self, monkeypatch, chat):
         def test(*args, **kwargs):
             return args[0] == chat.id and args[1] == 'test'
@@ -238,11 +253,11 @@ class TestChat(object):
         assert chat.send_poll('test_poll')
 
     def test_equality(self):
-        a = Chat(self.id, self.title, self.type)
-        b = Chat(self.id, self.title, self.type)
-        c = Chat(self.id, '', '')
-        d = Chat(0, self.title, self.type)
-        e = User(self.id, '', False)
+        a = Chat(self.id_, self.title, self.type_)
+        b = Chat(self.id_, self.title, self.type_)
+        c = Chat(self.id_, '', '')
+        d = Chat(0, self.title, self.type_)
+        e = User(self.id_, '', False)
 
         assert a == b
         assert hash(a) == hash(b)
