@@ -23,7 +23,7 @@ from telegram import constants
 from telegram.error import BadRequest
 
 
-class TestConstants(object):
+class TestConstants:
     @flaky(3, 1)
     @pytest.mark.timeout(10)
     def test_max_message_length(self, bot, chat_id):
