@@ -28,7 +28,7 @@ def force_reply():
     return ForceReply(TestForceReply.force_reply, TestForceReply.selective)
 
 
-class TestForceReply(object):
+class TestForceReply:
     force_reply = True
     selective = True
 
