@@ -32,14 +32,14 @@ def game():
                 animation=TestGame.animation)
 
 
-class TestGame(object):
+class TestGame:
     title = 'Python-telegram-bot Test Game'
     description = 'description'
-    photo = [PhotoSize('Blah', 640, 360, file_size=0)]
+    photo = [PhotoSize('Blah', 'ElseBlah', 640, 360, file_size=0)]
     text = (b'\\U0001f469\\u200d\\U0001f469\\u200d\\U0001f467'
             b'\\u200d\\U0001f467\\U0001f431http://google.com').decode('unicode-escape')
     text_entities = [MessageEntity(13, 17, MessageEntity.URL)]
-    animation = Animation('blah', 320, 180, 1)
+    animation = Animation('blah', 'unique_id', 320, 180, 1)
 
     def test_de_json_required(self, bot):
         json_dict = {
