@@ -24,28 +24,57 @@ import pytest
 from telegram import Sticker
 from telegram import Update
 from telegram import User
+from telegram import MessageEntity
 from telegram.message import Message
 from telegram.utils import helpers
-from telegram.utils.helpers import _UtcOffsetTimezone, _datetime_to_float_timestamp
+from telegram.utils.helpers import _datetime_to_float_timestamp
 
 
 # sample time specification values categorised into absolute / delta / time-of-day
-ABSOLUTE_TIME_SPECS = [dtm.datetime.now(tz=_UtcOffsetTimezone(dtm.timedelta(hours=-7))),
+ABSOLUTE_TIME_SPECS = [dtm.datetime.now(tz=dtm.timezone(dtm.timedelta(hours=-7))),
                        dtm.datetime.utcnow()]
 DELTA_TIME_SPECS = [dtm.timedelta(hours=3, seconds=42, milliseconds=2), 30, 7.5]
-TIME_OF_DAY_TIME_SPECS = [dtm.time(12, 42, tzinfo=_UtcOffsetTimezone(dtm.timedelta(hours=-7))),
+TIME_OF_DAY_TIME_SPECS = [dtm.time(12, 42, tzinfo=dtm.timezone(dtm.timedelta(hours=-7))),
                           dtm.time(12, 42)]
 RELATIVE_TIME_SPECS = DELTA_TIME_SPECS + TIME_OF_DAY_TIME_SPECS
 TIME_SPECS = ABSOLUTE_TIME_SPECS + RELATIVE_TIME_SPECS
 
 
-class TestHelpers(object):
+class TestHelpers:
     def test_escape_markdown(self):
         test_str = '*bold*, _italic_, `code`, [text_link](http://github.com/)'
-        expected_str = '\*bold\*, \_italic\_, \`code\`, \[text\_link](http://github.com/)'
+        expected_str = r'\*bold\*, \_italic\_, \`code\`, \[text\_link](http://github.com/)'
 
         assert expected_str == helpers.escape_markdown(test_str)
 
+    def test_escape_markdown_v2(self):
+        test_str = 'a_b*c[d]e (fg) h~I`>JK#L+MN -O=|p{qr}s.t! u'
+        expected_str = r'a\_b\*c\[d\]e \(fg\) h\~I\`\>JK\#L\+MN \-O\=\|p\{qr\}s\.t\! u'
+
+        assert expected_str == helpers.escape_markdown(test_str, version=2)
+
+    def test_escape_markdown_v2_monospaced(self):
+
+        test_str = r'mono/pre: `abc` \int (`\some \`stuff)'
+        expected_str = 'mono/pre: \\`abc\\` \\\\int (\\`\\\\some \\\\\\`stuff)'
+
+        assert expected_str == helpers.escape_markdown(test_str, version=2,
+                                                       entity_type=MessageEntity.PRE)
+        assert expected_str == helpers.escape_markdown(test_str, version=2,
+                                                       entity_type=MessageEntity.CODE)
+
+    def test_escape_markdown_v2_text_link(self):
+
+        test_str = 'https://url.containing/funny)cha)\\ra\\)cter\\s'
+        expected_str = 'https://url.containing/funny\\)cha\\)\\\\ra\\\\\\)cter\\\\s'
+
+        assert expected_str == helpers.escape_markdown(test_str, version=2,
+                                                       entity_type=MessageEntity.TEXT_LINK)
+
+    def test_markdown_invalid_version(self):
+        with pytest.raises(ValueError):
+            helpers.escape_markdown('abc', version=-1)
+
     def test_to_float_timestamp_absolute_naive(self):
         """Conversion from timezone-naive datetime to timestamp.
         Naive datetimes should be assumed to be in UTC.
@@ -113,8 +142,16 @@ class TestHelpers(object):
         # this 'convenience' behaviour has been left left for backwards compatibility
         assert helpers.to_timestamp(None) is None
 
-    def test_from_timestamp(self):
-        assert helpers.from_timestamp(1573431976) == dtm.datetime(2019, 11, 11, 0, 26, 16)
+    def test_from_timestamp_naive(self):
+        datetime = dtm.datetime(2019, 11, 11, 0, 26, 16, tzinfo=None)
+        assert helpers.from_timestamp(1573431976, tzinfo=None) == datetime
+
+    def test_from_timestamp_aware(self, timezone):
+        # we're parametrizing this with two different UTC offsets to exclude the possibility
+        # of an xpass when the test is run in a timezone with the same UTC offset
+        datetime = dtm.datetime(2019, 11, 11, 0, 26, 16, 10**5, tzinfo=timezone)
+        assert (helpers.from_timestamp(1573431976.1 - timezone.utcoffset(None).total_seconds())
+                == datetime)
 
     def test_create_deep_linked_url(self):
         username = 'JamesTheMock'
@@ -161,7 +198,8 @@ class TestHelpers(object):
         assert helpers.effective_message_type(test_message) == 'text'
         test_message.text = None
 
-        test_message = build_test_message(sticker=Sticker('sticker_id', 50, 50, False))
+        test_message = build_test_message(sticker=Sticker('sticker_id', 'unique_id',
+                                          50, 50, False))
         assert helpers.effective_message_type(test_message) == 'sticker'
         test_message.sticker = None
 
@@ -188,3 +226,8 @@ class TestHelpers(object):
         expected = '[the name](tg://user?id=1)'
 
         assert expected == helpers.mention_markdown(1, 'the name')
+
+    def test_mention_markdown_2(self):
+        expected = r'[the\_name](tg://user?id=1)'
+
+        assert expected == helpers.mention_markdown(1, 'the_name')
