@@ -20,7 +20,7 @@
 import pytest
 from flaky import flaky
 
-from telegram import InlineKeyboardButton, InlineKeyboardMarkup
+from telegram import InlineKeyboardButton, InlineKeyboardMarkup, ReplyMarkup
 
 
 @pytest.fixture(scope='class')
@@ -28,7 +28,7 @@ def inline_keyboard_markup():
     return InlineKeyboardMarkup(TestInlineKeyboardMarkup.inline_keyboard)
 
 
-class TestInlineKeyboardMarkup(object):
+class TestInlineKeyboardMarkup:
     inline_keyboard = [[
         InlineKeyboardButton(text='button1', callback_data='data1'),
         InlineKeyboardButton(text='button2', callback_data='data2')
@@ -68,6 +68,26 @@ class TestInlineKeyboardMarkup(object):
     def test_expected_values(self, inline_keyboard_markup):
         assert inline_keyboard_markup.inline_keyboard == self.inline_keyboard
 
+    def test_expected_values_empty_switch(self, inline_keyboard_markup, bot, monkeypatch):
+        def test(url, data, reply_to_message_id=None, disable_notification=None,
+                 reply_markup=None, timeout=None, **kwargs):
+            if reply_markup is not None:
+                if isinstance(reply_markup, ReplyMarkup):
+                    data['reply_markup'] = reply_markup.to_json()
+                else:
+                    data['reply_markup'] = reply_markup
+
+            assert bool('"switch_inline_query": ""' in data['reply_markup'])
+            assert bool('"switch_inline_query_current_chat": ""' in data['reply_markup'])
+
+        inline_keyboard_markup.inline_keyboard[0][0].callback_data = None
+        inline_keyboard_markup.inline_keyboard[0][0].switch_inline_query = ''
+        inline_keyboard_markup.inline_keyboard[0][1].callback_data = None
+        inline_keyboard_markup.inline_keyboard[0][1].switch_inline_query_current_chat = ''
+
+        monkeypatch.setattr(bot, '_message', test)
+        bot.send_message(123, 'test', reply_markup=inline_keyboard_markup)
+
     def test_to_dict(self, inline_keyboard_markup):
         inline_keyboard_markup_dict = inline_keyboard_markup.to_dict()
 
