@@ -26,7 +26,7 @@ from telegram import (InputTextMessageContent, InlineQueryResultCachedAudio, Inl
 @pytest.fixture(scope='class')
 def inline_query_result_cached_audio():
     return InlineQueryResultCachedAudio(
-        TestInlineQueryResultCachedAudio.id,
+        TestInlineQueryResultCachedAudio.id_,
         TestInlineQueryResultCachedAudio.audio_file_id,
         caption=TestInlineQueryResultCachedAudio.caption,
         parse_mode=TestInlineQueryResultCachedAudio.parse_mode,
@@ -34,9 +34,9 @@ def inline_query_result_cached_audio():
         reply_markup=TestInlineQueryResultCachedAudio.reply_markup)
 
 
-class TestInlineQueryResultCachedAudio(object):
-    id = 'id'
-    type = 'audio'
+class TestInlineQueryResultCachedAudio:
+    id_ = 'id'
+    type_ = 'audio'
     audio_file_id = 'audio file id'
     caption = 'caption'
     parse_mode = 'HTML'
@@ -44,8 +44,8 @@ class TestInlineQueryResultCachedAudio(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_cached_audio):
-        assert inline_query_result_cached_audio.type == self.type
-        assert inline_query_result_cached_audio.id == self.id
+        assert inline_query_result_cached_audio.type == self.type_
+        assert inline_query_result_cached_audio.id == self.id_
         assert inline_query_result_cached_audio.audio_file_id == self.audio_file_id
         assert inline_query_result_cached_audio.caption == self.caption
         assert inline_query_result_cached_audio.parse_mode == self.parse_mode
@@ -73,11 +73,11 @@ class TestInlineQueryResultCachedAudio(object):
                 == inline_query_result_cached_audio.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultCachedAudio(self.id, self.audio_file_id)
-        b = InlineQueryResultCachedAudio(self.id, self.audio_file_id)
-        c = InlineQueryResultCachedAudio(self.id, '')
+        a = InlineQueryResultCachedAudio(self.id_, self.audio_file_id)
+        b = InlineQueryResultCachedAudio(self.id_, self.audio_file_id)
+        c = InlineQueryResultCachedAudio(self.id_, '')
         d = InlineQueryResultCachedAudio('', self.audio_file_id)
-        e = InlineQueryResultCachedVoice(self.id, '', '')
+        e = InlineQueryResultCachedVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
