@@ -26,7 +26,7 @@ from telegram import (InlineQueryResultCachedDocument, InlineKeyboardButton, Inl
 @pytest.fixture(scope='class')
 def inline_query_result_cached_document():
     return InlineQueryResultCachedDocument(
-        TestInlineQueryResultCachedDocument.id,
+        TestInlineQueryResultCachedDocument.id_,
         TestInlineQueryResultCachedDocument.title,
         TestInlineQueryResultCachedDocument.document_file_id,
         caption=TestInlineQueryResultCachedDocument.caption,
@@ -36,9 +36,9 @@ def inline_query_result_cached_document():
         reply_markup=TestInlineQueryResultCachedDocument.reply_markup)
 
 
-class TestInlineQueryResultCachedDocument(object):
-    id = 'id'
-    type = 'document'
+class TestInlineQueryResultCachedDocument:
+    id_ = 'id'
+    type_ = 'document'
     document_file_id = 'document file id'
     title = 'title'
     caption = 'caption'
@@ -48,8 +48,8 @@ class TestInlineQueryResultCachedDocument(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_cached_document):
-        assert inline_query_result_cached_document.id == self.id
-        assert inline_query_result_cached_document.type == self.type
+        assert inline_query_result_cached_document.id == self.id_
+        assert inline_query_result_cached_document.type == self.type_
         assert inline_query_result_cached_document.document_file_id == self.document_file_id
         assert inline_query_result_cached_document.title == self.title
         assert inline_query_result_cached_document.caption == self.caption
@@ -84,11 +84,11 @@ class TestInlineQueryResultCachedDocument(object):
                 == inline_query_result_cached_document.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultCachedDocument(self.id, self.title, self.document_file_id)
-        b = InlineQueryResultCachedDocument(self.id, self.title, self.document_file_id)
-        c = InlineQueryResultCachedDocument(self.id, self.title, '')
+        a = InlineQueryResultCachedDocument(self.id_, self.title, self.document_file_id)
+        b = InlineQueryResultCachedDocument(self.id_, self.title, self.document_file_id)
+        c = InlineQueryResultCachedDocument(self.id_, self.title, '')
         d = InlineQueryResultCachedDocument('', self.title, self.document_file_id)
-        e = InlineQueryResultCachedVoice(self.id, '', '')
+        e = InlineQueryResultCachedVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
