@@ -26,7 +26,7 @@ from telegram import (InputTextMessageContent, InlineQueryResultCachedPhoto, Inl
 @pytest.fixture(scope='class')
 def inline_query_result_cached_photo():
     return InlineQueryResultCachedPhoto(
-        TestInlineQueryResultCachedPhoto.id,
+        TestInlineQueryResultCachedPhoto.id_,
         TestInlineQueryResultCachedPhoto.photo_file_id,
         title=TestInlineQueryResultCachedPhoto.title,
         description=TestInlineQueryResultCachedPhoto.description,
@@ -36,9 +36,9 @@ def inline_query_result_cached_photo():
         reply_markup=TestInlineQueryResultCachedPhoto.reply_markup)
 
 
-class TestInlineQueryResultCachedPhoto(object):
-    id = 'id'
-    type = 'photo'
+class TestInlineQueryResultCachedPhoto:
+    id_ = 'id'
+    type_ = 'photo'
     photo_file_id = 'photo file id'
     title = 'title'
     description = 'description'
@@ -48,8 +48,8 @@ class TestInlineQueryResultCachedPhoto(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_cached_photo):
-        assert inline_query_result_cached_photo.type == self.type
-        assert inline_query_result_cached_photo.id == self.id
+        assert inline_query_result_cached_photo.type == self.type_
+        assert inline_query_result_cached_photo.id == self.id_
         assert inline_query_result_cached_photo.photo_file_id == self.photo_file_id
         assert inline_query_result_cached_photo.title == self.title
         assert inline_query_result_cached_photo.description == self.description
@@ -83,11 +83,11 @@ class TestInlineQueryResultCachedPhoto(object):
                 == inline_query_result_cached_photo.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultCachedPhoto(self.id, self.photo_file_id)
-        b = InlineQueryResultCachedPhoto(self.id, self.photo_file_id)
-        c = InlineQueryResultCachedPhoto(self.id, '')
+        a = InlineQueryResultCachedPhoto(self.id_, self.photo_file_id)
+        b = InlineQueryResultCachedPhoto(self.id_, self.photo_file_id)
+        c = InlineQueryResultCachedPhoto(self.id_, '')
         d = InlineQueryResultCachedPhoto('', self.photo_file_id)
-        e = InlineQueryResultCachedVoice(self.id, '', '')
+        e = InlineQueryResultCachedVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
