@@ -26,7 +26,7 @@ from telegram import (InlineKeyboardButton, InputTextMessageContent, InlineQuery
 @pytest.fixture(scope='class')
 def inline_query_result_gif():
     return InlineQueryResultGif(
-        TestInlineQueryResultGif.id,
+        TestInlineQueryResultGif.id_,
         TestInlineQueryResultGif.gif_url,
         TestInlineQueryResultGif.thumb_url,
         gif_width=TestInlineQueryResultGif.gif_width,
@@ -36,17 +36,19 @@ def inline_query_result_gif():
         caption=TestInlineQueryResultGif.caption,
         parse_mode=TestInlineQueryResultGif.parse_mode,
         input_message_content=TestInlineQueryResultGif.input_message_content,
-        reply_markup=TestInlineQueryResultGif.reply_markup)
+        reply_markup=TestInlineQueryResultGif.reply_markup,
+        thumb_mime_type=TestInlineQueryResultGif.thumb_mime_type)
 
 
-class TestInlineQueryResultGif(object):
-    id = 'id'
-    type = 'gif'
+class TestInlineQueryResultGif:
+    id_ = 'id'
+    type_ = 'gif'
     gif_url = 'gif url'
     gif_width = 10
     gif_height = 15
     gif_duration = 1
     thumb_url = 'thumb url'
+    thumb_mime_type = 'image/jpeg'
     title = 'title'
     caption = 'caption'
     parse_mode = 'HTML'
@@ -54,13 +56,14 @@ class TestInlineQueryResultGif(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_gif):
-        assert inline_query_result_gif.type == self.type
-        assert inline_query_result_gif.id == self.id
+        assert inline_query_result_gif.type == self.type_
+        assert inline_query_result_gif.id == self.id_
         assert inline_query_result_gif.gif_url == self.gif_url
         assert inline_query_result_gif.gif_width == self.gif_width
         assert inline_query_result_gif.gif_height == self.gif_height
         assert inline_query_result_gif.gif_duration == self.gif_duration
         assert inline_query_result_gif.thumb_url == self.thumb_url
+        assert inline_query_result_gif.thumb_mime_type == self.thumb_mime_type
         assert inline_query_result_gif.title == self.title
         assert inline_query_result_gif.caption == self.caption
         assert inline_query_result_gif.parse_mode == self.parse_mode
@@ -79,6 +82,8 @@ class TestInlineQueryResultGif(object):
         assert inline_query_result_gif_dict['gif_height'] == inline_query_result_gif.gif_height
         assert inline_query_result_gif_dict['gif_duration'] == inline_query_result_gif.gif_duration
         assert inline_query_result_gif_dict['thumb_url'] == inline_query_result_gif.thumb_url
+        assert (inline_query_result_gif_dict['thumb_mime_type']
+                == inline_query_result_gif.thumb_mime_type)
         assert inline_query_result_gif_dict['title'] == inline_query_result_gif.title
         assert inline_query_result_gif_dict['caption'] == inline_query_result_gif.caption
         assert inline_query_result_gif_dict['parse_mode'] == inline_query_result_gif.parse_mode
@@ -88,11 +93,11 @@ class TestInlineQueryResultGif(object):
                 == inline_query_result_gif.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultGif(self.id, self.gif_url, self.thumb_url)
-        b = InlineQueryResultGif(self.id, self.gif_url, self.thumb_url)
-        c = InlineQueryResultGif(self.id, '', self.thumb_url)
+        a = InlineQueryResultGif(self.id_, self.gif_url, self.thumb_url)
+        b = InlineQueryResultGif(self.id_, self.gif_url, self.thumb_url)
+        c = InlineQueryResultGif(self.id_, '', self.thumb_url)
         d = InlineQueryResultGif('', self.gif_url, self.thumb_url)
-        e = InlineQueryResultVoice(self.id, '', '')
+        e = InlineQueryResultVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
