@@ -26,7 +26,7 @@ from telegram import (InputTextMessageContent, InlineQueryResultLocation, Inline
 @pytest.fixture(scope='class')
 def inline_query_result_location():
     return InlineQueryResultLocation(
-        TestInlineQueryResultLocation.id,
+        TestInlineQueryResultLocation.id_,
         TestInlineQueryResultLocation.latitude,
         TestInlineQueryResultLocation.longitude,
         TestInlineQueryResultLocation.title,
@@ -38,9 +38,9 @@ def inline_query_result_location():
         reply_markup=TestInlineQueryResultLocation.reply_markup)
 
 
-class TestInlineQueryResultLocation(object):
-    id = 'id'
-    type = 'location'
+class TestInlineQueryResultLocation:
+    id_ = 'id'
+    type_ = 'location'
     latitude = 0.0
     longitude = 1.0
     title = 'title'
@@ -52,8 +52,8 @@ class TestInlineQueryResultLocation(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_location):
-        assert inline_query_result_location.id == self.id
-        assert inline_query_result_location.type == self.type
+        assert inline_query_result_location.id == self.id_
+        assert inline_query_result_location.type == self.type_
         assert inline_query_result_location.latitude == self.latitude
         assert inline_query_result_location.longitude == self.longitude
         assert inline_query_result_location.title == self.title
@@ -90,11 +90,11 @@ class TestInlineQueryResultLocation(object):
                 == inline_query_result_location.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultLocation(self.id, self.longitude, self.latitude, self.title)
-        b = InlineQueryResultLocation(self.id, self.longitude, self.latitude, self.title)
-        c = InlineQueryResultLocation(self.id, 0, self.latitude, self.title)
+        a = InlineQueryResultLocation(self.id_, self.longitude, self.latitude, self.title)
+        b = InlineQueryResultLocation(self.id_, self.longitude, self.latitude, self.title)
+        c = InlineQueryResultLocation(self.id_, 0, self.latitude, self.title)
         d = InlineQueryResultLocation('', self.longitude, self.latitude, self.title)
-        e = InlineQueryResultVoice(self.id, '', '')
+        e = InlineQueryResultVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
