@@ -26,7 +26,7 @@ from telegram import (InlineQueryResultMpeg4Gif, InlineKeyboardButton, InlineQue
 @pytest.fixture(scope='class')
 def inline_query_result_mpeg4_gif():
     return InlineQueryResultMpeg4Gif(
-        TestInlineQueryResultMpeg4Gif.id,
+        TestInlineQueryResultMpeg4Gif.id_,
         TestInlineQueryResultMpeg4Gif.mpeg4_url,
         TestInlineQueryResultMpeg4Gif.thumb_url,
         mpeg4_width=TestInlineQueryResultMpeg4Gif.mpeg4_width,
@@ -36,17 +36,19 @@ def inline_query_result_mpeg4_gif():
         caption=TestInlineQueryResultMpeg4Gif.caption,
         parse_mode=TestInlineQueryResultMpeg4Gif.parse_mode,
         input_message_content=TestInlineQueryResultMpeg4Gif.input_message_content,
-        reply_markup=TestInlineQueryResultMpeg4Gif.reply_markup)
+        reply_markup=TestInlineQueryResultMpeg4Gif.reply_markup,
+        thumb_mime_type=TestInlineQueryResultMpeg4Gif.thumb_mime_type)
 
 
-class TestInlineQueryResultMpeg4Gif(object):
-    id = 'id'
-    type = 'mpeg4_gif'
+class TestInlineQueryResultMpeg4Gif:
+    id_ = 'id'
+    type_ = 'mpeg4_gif'
     mpeg4_url = 'mpeg4 url'
     mpeg4_width = 10
     mpeg4_height = 15
     mpeg4_duration = 1
     thumb_url = 'thumb url'
+    thumb_mime_type = 'image/jpeg'
     title = 'title'
     caption = 'caption'
     parse_mode = 'Markdown'
@@ -54,13 +56,14 @@ class TestInlineQueryResultMpeg4Gif(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_mpeg4_gif):
-        assert inline_query_result_mpeg4_gif.type == self.type
-        assert inline_query_result_mpeg4_gif.id == self.id
+        assert inline_query_result_mpeg4_gif.type == self.type_
+        assert inline_query_result_mpeg4_gif.id == self.id_
         assert inline_query_result_mpeg4_gif.mpeg4_url == self.mpeg4_url
         assert inline_query_result_mpeg4_gif.mpeg4_width == self.mpeg4_width
         assert inline_query_result_mpeg4_gif.mpeg4_height == self.mpeg4_height
         assert inline_query_result_mpeg4_gif.mpeg4_duration == self.mpeg4_duration
         assert inline_query_result_mpeg4_gif.thumb_url == self.thumb_url
+        assert inline_query_result_mpeg4_gif.thumb_mime_type == self.thumb_mime_type
         assert inline_query_result_mpeg4_gif.title == self.title
         assert inline_query_result_mpeg4_gif.caption == self.caption
         assert inline_query_result_mpeg4_gif.parse_mode == self.parse_mode
@@ -84,6 +87,8 @@ class TestInlineQueryResultMpeg4Gif(object):
                 == inline_query_result_mpeg4_gif.mpeg4_duration)
         assert (inline_query_result_mpeg4_gif_dict['thumb_url']
                 == inline_query_result_mpeg4_gif.thumb_url)
+        assert (inline_query_result_mpeg4_gif_dict['thumb_mime_type']
+                == inline_query_result_mpeg4_gif.thumb_mime_type)
         assert inline_query_result_mpeg4_gif_dict['title'] == inline_query_result_mpeg4_gif.title
         assert (inline_query_result_mpeg4_gif_dict['caption']
                 == inline_query_result_mpeg4_gif.caption)
@@ -95,11 +100,11 @@ class TestInlineQueryResultMpeg4Gif(object):
                 == inline_query_result_mpeg4_gif.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultMpeg4Gif(self.id, self.mpeg4_url, self.thumb_url)
-        b = InlineQueryResultMpeg4Gif(self.id, self.mpeg4_url, self.thumb_url)
-        c = InlineQueryResultMpeg4Gif(self.id, '', self.thumb_url)
+        a = InlineQueryResultMpeg4Gif(self.id_, self.mpeg4_url, self.thumb_url)
+        b = InlineQueryResultMpeg4Gif(self.id_, self.mpeg4_url, self.thumb_url)
+        c = InlineQueryResultMpeg4Gif(self.id_, '', self.thumb_url)
         d = InlineQueryResultMpeg4Gif('', self.mpeg4_url, self.thumb_url)
-        e = InlineQueryResultVoice(self.id, '', '')
+        e = InlineQueryResultVoice(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
