@@ -26,8 +26,8 @@ from telegram import (InlineKeyboardButton, InputTextMessageContent, InlineQuery
 @pytest.fixture(scope='class')
 def inline_query_result_voice():
     return InlineQueryResultVoice(
-        type=TestInlineQueryResultVoice.type,
-        id=TestInlineQueryResultVoice.id,
+        type=TestInlineQueryResultVoice.type_,
+        id=TestInlineQueryResultVoice.id_,
         voice_url=TestInlineQueryResultVoice.voice_url,
         title=TestInlineQueryResultVoice.title,
         voice_duration=TestInlineQueryResultVoice.voice_duration,
@@ -37,9 +37,9 @@ def inline_query_result_voice():
         reply_markup=TestInlineQueryResultVoice.reply_markup)
 
 
-class TestInlineQueryResultVoice(object):
-    id = 'id'
-    type = 'voice'
+class TestInlineQueryResultVoice:
+    id_ = 'id'
+    type_ = 'voice'
     voice_url = 'voice url'
     title = 'title'
     voice_duration = 'voice_duration'
@@ -49,8 +49,8 @@ class TestInlineQueryResultVoice(object):
     reply_markup = InlineKeyboardMarkup([[InlineKeyboardButton('reply_markup')]])
 
     def test_expected_values(self, inline_query_result_voice):
-        assert inline_query_result_voice.type == self.type
-        assert inline_query_result_voice.id == self.id
+        assert inline_query_result_voice.type == self.type_
+        assert inline_query_result_voice.id == self.id_
         assert inline_query_result_voice.voice_url == self.voice_url
         assert inline_query_result_voice.title == self.title
         assert inline_query_result_voice.voice_duration == self.voice_duration
@@ -78,11 +78,11 @@ class TestInlineQueryResultVoice(object):
                 == inline_query_result_voice.reply_markup.to_dict())
 
     def test_equality(self):
-        a = InlineQueryResultVoice(self.id, self.voice_url, self.title)
-        b = InlineQueryResultVoice(self.id, self.voice_url, self.title)
-        c = InlineQueryResultVoice(self.id, '', self.title)
+        a = InlineQueryResultVoice(self.id_, self.voice_url, self.title)
+        b = InlineQueryResultVoice(self.id_, self.voice_url, self.title)
+        c = InlineQueryResultVoice(self.id_, '', self.title)
         d = InlineQueryResultVoice('', self.voice_url, self.title)
-        e = InlineQueryResultAudio(self.id, '', '')
+        e = InlineQueryResultAudio(self.id_, '', '')
 
         assert a == b
         assert hash(a) == hash(b)
