@@ -29,7 +29,7 @@ def input_contact_message_content():
                                       last_name=TestInputContactMessageContent.last_name)
 
 
-class TestInputContactMessageContent(object):
+class TestInputContactMessageContent:
     phone_number = 'phone number'
     first_name = 'first name'
     last_name = 'last name'
