@@ -51,7 +51,7 @@ def message(bot):
     return Message(1, User(1, '', False), None, Chat(1, ''), bot=bot)
 
 
-class TestMessageHandler(object):
+class TestMessageHandler:
     test_flag = False
     SRE_TYPE = type(re.match("", ""))
 
