@@ -24,20 +24,20 @@ from telegram import PassportElementErrorReverseSide, PassportElementErrorSelfie
 
 @pytest.fixture(scope='class')
 def passport_element_error_reverse_side():
-    return PassportElementErrorReverseSide(TestPassportElementErrorReverseSide.type,
+    return PassportElementErrorReverseSide(TestPassportElementErrorReverseSide.type_,
                                            TestPassportElementErrorReverseSide.file_hash,
                                            TestPassportElementErrorReverseSide.message)
 
 
-class TestPassportElementErrorReverseSide(object):
+class TestPassportElementErrorReverseSide:
     source = 'reverse_side'
-    type = 'test_type'
+    type_ = 'test_type'
     file_hash = 'file_hash'
     message = 'Error message'
 
     def test_expected_values(self, passport_element_error_reverse_side):
         assert passport_element_error_reverse_side.source == self.source
-        assert passport_element_error_reverse_side.type == self.type
+        assert passport_element_error_reverse_side.type == self.type_
         assert passport_element_error_reverse_side.file_hash == self.file_hash
         assert passport_element_error_reverse_side.message == self.message
 
@@ -55,12 +55,12 @@ class TestPassportElementErrorReverseSide(object):
                 == passport_element_error_reverse_side.message)
 
     def test_equality(self):
-        a = PassportElementErrorReverseSide(self.type, self.file_hash, self.message)
-        b = PassportElementErrorReverseSide(self.type, self.file_hash, self.message)
-        c = PassportElementErrorReverseSide(self.type, '', '')
+        a = PassportElementErrorReverseSide(self.type_, self.file_hash, self.message)
+        b = PassportElementErrorReverseSide(self.type_, self.file_hash, self.message)
+        c = PassportElementErrorReverseSide(self.type_, '', '')
         d = PassportElementErrorReverseSide('', self.file_hash, '')
         e = PassportElementErrorReverseSide('', '', self.message)
-        f = PassportElementErrorSelfie(self.type, self.file_hash, self.message)
+        f = PassportElementErrorSelfie(self.type_, self.file_hash, self.message)
 
         assert a == b
         assert hash(a) == hash(b)
