@@ -29,17 +29,55 @@ import logging
 import os
 import pickle
 from collections import defaultdict
+from time import sleep
 
 import pytest
 
 from telegram import Update, Message, User, Chat, MessageEntity
 from telegram.ext import BasePersistence, Updater, ConversationHandler, MessageHandler, Filters, \
-    PicklePersistence, CommandHandler, DictPersistence, TypeHandler
+    PicklePersistence, CommandHandler, DictPersistence, TypeHandler, JobQueue
+
+
+@pytest.fixture(autouse=True)
+def change_directory(tmp_path):
+    orig_dir = os.getcwd()
+    # Switch to a temporary directory so we don't have to worry about cleaning up files
+    # (str() for py<3.6)
+    os.chdir(str(tmp_path))
+    yield
+    # Go back to original directory
+    os.chdir(orig_dir)
 
 
 @pytest.fixture(scope="function")
 def base_persistence():
-    return BasePersistence(store_chat_data=True, store_user_data=True, store_bot_data=True)
+    class OwnPersistence(BasePersistence):
+
+        def get_bot_data(self):
+            raise NotImplementedError
+
+        def get_chat_data(self):
+            raise NotImplementedError
+
+        def get_user_data(self):
+            raise NotImplementedError
+
+        def get_conversations(self, name):
+            raise NotImplementedError
+
+        def update_bot_data(self, data):
+            raise NotImplementedError
+
+        def update_chat_data(self, chat_id, data):
+            raise NotImplementedError
+
+        def update_conversation(self, name, key, new_state):
+            raise NotImplementedError
+
+        def update_user_data(self, user_id, data):
+            raise NotImplementedError
+
+    return OwnPersistence(store_chat_data=True, store_user_data=True, store_bot_data=True)
 
 
 @pytest.fixture(scope="function")
@@ -76,27 +114,25 @@ def updater(bot, base_persistence):
     return u
 
 
-class TestBasePersistence(object):
+@pytest.fixture(scope='function')
+def job_queue(bot):
+    jq = JobQueue()
+    yield jq
+    jq.stop()
+
+
+class TestBasePersistence:
 
     def test_creation(self, base_persistence):
         assert base_persistence.store_chat_data
         assert base_persistence.store_user_data
-        with pytest.raises(NotImplementedError):
-            base_persistence.get_bot_data()
-        with pytest.raises(NotImplementedError):
-            base_persistence.get_chat_data()
-        with pytest.raises(NotImplementedError):
-            base_persistence.get_user_data()
-        with pytest.raises(NotImplementedError):
-            base_persistence.get_conversations("test")
-        with pytest.raises(NotImplementedError):
-            base_persistence.update_bot_data(None)
-        with pytest.raises(NotImplementedError):
-            base_persistence.update_chat_data(None, None)
-        with pytest.raises(NotImplementedError):
-            base_persistence.update_user_data(None, None)
-        with pytest.raises(NotImplementedError):
-            base_persistence.update_conversation(None, None, None)
+        assert base_persistence.store_bot_data
+
+    def test_abstract_methods(self):
+        with pytest.raises(TypeError, match=('get_bot_data, get_chat_data, get_conversations, '
+                                             'get_user_data, update_bot_data, update_chat_data, '
+                                             'update_conversation, update_user_data')):
+            BasePersistence()
 
     def test_implementation(self, updater, base_persistence):
         dp = updater.dispatcher
@@ -108,8 +144,6 @@ class TestBasePersistence(object):
         with pytest.raises(ValueError, match="if dispatcher has no persistence"):
             dp.add_handler(ConversationHandler([], {}, [], persistent=True, name="My Handler"))
         dp.persistence = base_persistence
-        with pytest.raises(NotImplementedError):
-            dp.add_handler(ConversationHandler([], {}, [], persistent=True, name="My Handler"))
 
     def test_dispatcher_integration_init(self, bot, base_persistence, chat_data, user_data,
                                          bot_data):
@@ -253,7 +287,7 @@ class TestBasePersistence(object):
 
         dp.persistence = base_persistence
 
-        class MyUpdate(object):
+        class MyUpdate:
             pass
 
         dp.add_handler(TypeHandler(MyUpdate, lambda *_: None))
@@ -310,15 +344,12 @@ def bad_pickle_files():
         with open(name, 'w') as f:
             f.write('(())')
     yield True
-    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_bot_data',
-                 'pickletest_conversations', 'pickletest']:
-        os.remove(name)
 
 
 @pytest.fixture(scope='function')
 def good_pickle_files(user_data, chat_data, bot_data, conversations):
-    all = {'user_data': user_data, 'chat_data': chat_data,
-           'bot_data': bot_data, 'conversations': conversations}
+    data = {'user_data': user_data, 'chat_data': chat_data,
+            'bot_data': bot_data, 'conversations': conversations}
     with open('pickletest_user_data', 'wb') as f:
         pickle.dump(user_data, f)
     with open('pickletest_chat_data', 'wb') as f:
@@ -328,16 +359,13 @@ def good_pickle_files(user_data, chat_data, bot_data, conversations):
     with open('pickletest_conversations', 'wb') as f:
         pickle.dump(conversations, f)
     with open('pickletest', 'wb') as f:
-        pickle.dump(all, f)
+        pickle.dump(data, f)
     yield True
-    for name in ['pickletest_user_data', 'pickletest_chat_data', 'pickletest_bot_data',
-                 'pickletest_conversations', 'pickletest']:
-        os.remove(name)
 
 
 @pytest.fixture(scope='function')
 def pickle_files_wo_bot_data(user_data, chat_data, conversations):
-    all = {'user_data': user_data, 'chat_data': chat_data, 'conversations': conversations}
+    data = {'user_data': user_data, 'chat_data': chat_data, 'conversations': conversations}
     with open('pickletest_user_data', 'wb') as f:
         pickle.dump(user_data, f)
     with open('pickletest_chat_data', 'wb') as f:
@@ -345,11 +373,8 @@ def pickle_files_wo_bot_data(user_data, chat_data, conversations):
     with open('pickletest_conversations', 'wb') as f:
         pickle.dump(conversations, f)
     with open('pickletest', 'wb') as f:
-        pickle.dump(all, f)
+        pickle.dump(data, f)
     yield True
-    for name in ['pickletest_user_data', 'pickletest_chat_data',
-                 'pickletest_conversations', 'pickletest']:
-        os.remove(name)
 
 
 @pytest.fixture(scope='function')
@@ -360,7 +385,7 @@ def update(bot):
     return Update(0, message=message)
 
 
-class TestPickelPersistence(object):
+class TestPickelPersistence:
     def test_no_files_present_multi_file(self, pickle_persistence):
         assert pickle_persistence.get_user_data() == defaultdict(dict)
         assert pickle_persistence.get_user_data() == defaultdict(dict)
@@ -776,9 +801,6 @@ class TestPickelPersistence(object):
         assert pickle_persistence_2.get_bot_data()['test'] == 'Working3!'
 
     def test_flush_on_stop_only_bot(self, bot, update, pickle_persistence_only_bot):
-        os.remove('pickletest_user_data')
-        os.remove('pickletest_chat_data')
-        os.remove('pickletest_bot_data')
         u = Updater(bot=bot, persistence=pickle_persistence_only_bot)
         dp = u.dispatcher
         u.running = True
@@ -800,7 +822,6 @@ class TestPickelPersistence(object):
         assert pickle_persistence_2.get_bot_data()['my_test3'] == 'Working3!'
 
     def test_flush_on_stop_only_chat(self, bot, update, pickle_persistence_only_chat):
-        os.remove('pickletest_bot_data')
         u = Updater(bot=bot, persistence=pickle_persistence_only_chat)
         dp = u.dispatcher
         u.running = True
@@ -821,7 +842,6 @@ class TestPickelPersistence(object):
         assert pickle_persistence_2.get_bot_data() == {}
 
     def test_flush_on_stop_only_user(self, bot, update, pickle_persistence_only_user):
-        os.remove('pickletest_chat_data')
         u = Updater(bot=bot, persistence=pickle_persistence_only_user)
         dp = u.dispatcher
         u.running = True
@@ -923,16 +943,23 @@ class TestPickelPersistence(object):
         assert nested_ch.conversations[nested_ch._get_key(update)] == 1
         assert nested_ch.conversations == pickle_persistence.conversations['name3']
 
-    @classmethod
-    def teardown_class(cls):
-        try:
-            for name in ['pickletest_user_data', 'pickletest_chat_data',
-                         'pickletest_bot_data',
-                         'pickletest_conversations',
-                         'pickletest']:
-                os.remove(name)
-        except Exception:
-            pass
+    def test_with_job(self, job_queue, cdp, pickle_persistence):
+        def job_callback(context):
+            context.bot_data['test1'] = '456'
+            context.dispatcher.chat_data[123]['test2'] = '789'
+            context.dispatcher.user_data[789]['test3'] = '123'
+
+        cdp.persistence = pickle_persistence
+        job_queue.set_dispatcher(cdp)
+        job_queue.start()
+        job_queue.run_once(job_callback, 0.01)
+        sleep(0.05)
+        bot_data = pickle_persistence.get_bot_data()
+        assert bot_data == {'test1': '456'}
+        chat_data = pickle_persistence.get_chat_data()
+        assert chat_data[123] == {'test2': '789'}
+        user_data = pickle_persistence.get_user_data()
+        assert user_data[789] == {'test3': '123'}
 
 
 @pytest.fixture(scope='function')
@@ -957,7 +984,7 @@ def conversations_json(conversations):
               {"[123, 321]": 1, "[890, 890]": 2}}"""
 
 
-class TestDictPersistence(object):
+class TestDictPersistence:
     def test_no_json_given(self):
         dict_persistence = DictPersistence()
         assert dict_persistence.get_user_data() == defaultdict(dict)
@@ -1216,3 +1243,22 @@ class TestDictPersistence(object):
         assert ch.conversations == dict_persistence.conversations['name2']
         assert nested_ch.conversations[nested_ch._get_key(update)] == 1
         assert nested_ch.conversations == dict_persistence.conversations['name3']
+
+    def test_with_job(self, job_queue, cdp):
+        def job_callback(context):
+            context.bot_data['test1'] = '456'
+            context.dispatcher.chat_data[123]['test2'] = '789'
+            context.dispatcher.user_data[789]['test3'] = '123'
+
+        dict_persistence = DictPersistence()
+        cdp.persistence = dict_persistence
+        job_queue.set_dispatcher(cdp)
+        job_queue.start()
+        job_queue.run_once(job_callback, 0.01)
+        sleep(0.05)
+        bot_data = dict_persistence.get_bot_data()
+        assert bot_data == {'test1': '456'}
+        chat_data = dict_persistence.get_chat_data()
+        assert chat_data[123] == {'test2': '789'}
+        user_data = dict_persistence.get_user_data()
+        assert user_data[789] == {'test3': '123'}
