@@ -24,6 +24,7 @@ from flaky import flaky
 
 from telegram import Sticker, TelegramError, PhotoSize, InputFile
 from telegram.utils.helpers import escape_markdown
+from tests.conftest import expect_bad_request
 
 
 @pytest.fixture(scope='function')
@@ -35,8 +36,11 @@ def photo_file():
 
 @pytest.fixture(scope='class')
 def _photo(bot, chat_id):
-    with open('tests/data/telegram.jpg', 'rb') as f:
-        return bot.send_photo(chat_id, photo=f, timeout=50).photo
+    def func():
+        with open('tests/data/telegram.jpg', 'rb') as f:
+            return bot.send_photo(chat_id, photo=f, timeout=50).photo
+
+    return expect_bad_request(func, 'Type of file mismatch', 'Telegram did not accept the file.')
 
 
 @pytest.fixture(scope='class')
@@ -49,7 +53,7 @@ def photo(_photo):
     return _photo[1]
 
 
-class TestPhoto(object):
+class TestPhoto:
     width = 800
     height = 800
     caption = u'<b>PhotoTest</b> - *Caption*'
@@ -60,11 +64,15 @@ class TestPhoto(object):
         # Make sure file has been uploaded.
         assert isinstance(photo, PhotoSize)
         assert isinstance(photo.file_id, str)
+        assert isinstance(photo.file_unique_id, str)
         assert photo.file_id != ''
+        assert photo.file_unique_id != ''
 
         assert isinstance(thumb, PhotoSize)
         assert isinstance(thumb.file_id, str)
+        assert isinstance(thumb.file_unique_id, str)
         assert thumb.file_id != ''
+        assert thumb.file_unique_id != ''
 
     def test_expected_values(self, photo, thumb):
         assert photo.width == self.width
@@ -82,14 +90,18 @@ class TestPhoto(object):
 
         assert isinstance(message.photo[0], PhotoSize)
         assert isinstance(message.photo[0].file_id, str)
+        assert isinstance(message.photo[0].file_unique_id, str)
         assert message.photo[0].file_id != ''
+        assert message.photo[0].file_unique_id != ''
         assert message.photo[0].width == thumb.width
         assert message.photo[0].height == thumb.height
         assert message.photo[0].file_size == thumb.file_size
 
         assert isinstance(message.photo[1], PhotoSize)
         assert isinstance(message.photo[1].file_id, str)
+        assert isinstance(message.photo[1].file_unique_id, str)
         assert message.photo[1].file_id != ''
+        assert message.photo[1].file_unique_id != ''
         assert message.photo[1].width == photo.width
         assert message.photo[1].height == photo.height
         assert message.photo[1].file_size == photo.file_size
@@ -103,14 +115,18 @@ class TestPhoto(object):
                                  parse_mode='Markdown')
         assert isinstance(message.photo[0], PhotoSize)
         assert isinstance(message.photo[0].file_id, str)
+        assert isinstance(message.photo[0].file_unique_id, str)
         assert message.photo[0].file_id != ''
+        assert message.photo[0].file_unique_id != ''
         assert message.photo[0].width == thumb.width
         assert message.photo[0].height == thumb.height
         assert message.photo[0].file_size == thumb.file_size
 
         assert isinstance(message.photo[1], PhotoSize)
         assert isinstance(message.photo[1].file_id, str)
+        assert isinstance(message.photo[1].file_unique_id, str)
         assert message.photo[1].file_id != ''
+        assert message.photo[1].file_unique_id != ''
         assert message.photo[1].width == photo.width
         assert message.photo[1].height == photo.height
         assert message.photo[1].file_size == photo.file_size
@@ -125,14 +141,18 @@ class TestPhoto(object):
                                  parse_mode='HTML')
         assert isinstance(message.photo[0], PhotoSize)
         assert isinstance(message.photo[0].file_id, str)
+        assert isinstance(message.photo[0].file_unique_id, str)
         assert message.photo[0].file_id != ''
+        assert message.photo[0].file_unique_id != ''
         assert message.photo[0].width == thumb.width
         assert message.photo[0].height == thumb.height
         assert message.photo[0].file_size == thumb.file_size
 
         assert isinstance(message.photo[1], PhotoSize)
         assert isinstance(message.photo[1].file_id, str)
+        assert isinstance(message.photo[1].file_unique_id, str)
         assert message.photo[1].file_id != ''
+        assert message.photo[1].file_unique_id != ''
         assert message.photo[1].width == photo.width
         assert message.photo[1].height == photo.height
         assert message.photo[1].file_size == photo.file_size
@@ -175,12 +195,11 @@ class TestPhoto(object):
 
     @flaky(3, 1)
     @pytest.mark.timeout(10)
-    @pytest.mark.skip(reason='Doesnt work without API 4.5')
     def test_get_and_download(self, bot, photo):
         new_file = bot.getFile(photo.file_id)
 
         assert new_file.file_size == photo.file_size
-        assert new_file.file_id == photo.file_id
+        assert new_file.file_unique_id == photo.file_unique_id
         assert new_file.file_path.startswith('https://') is True
 
         new_file.download('telegram.jpg')
@@ -194,14 +213,18 @@ class TestPhoto(object):
 
         assert isinstance(message.photo[0], PhotoSize)
         assert isinstance(message.photo[0].file_id, str)
+        assert isinstance(message.photo[0].file_unique_id, str)
         assert message.photo[0].file_id != ''
+        assert message.photo[0].file_unique_id != ''
         assert message.photo[0].width == thumb.width
         assert message.photo[0].height == thumb.height
         assert message.photo[0].file_size == thumb.file_size
 
         assert isinstance(message.photo[1], PhotoSize)
         assert isinstance(message.photo[1].file_id, str)
+        assert isinstance(message.photo[1].file_unique_id, str)
         assert message.photo[1].file_id != ''
+        assert message.photo[1].file_unique_id != ''
         assert message.photo[1].width == photo.width
         assert message.photo[1].height == photo.height
         assert message.photo[1].file_size == photo.file_size
@@ -216,7 +239,9 @@ class TestPhoto(object):
 
         assert isinstance(photo, PhotoSize)
         assert isinstance(photo.file_id, str)
+        assert isinstance(photo.file_unique_id, str)
         assert photo.file_id != ''
+        assert photo.file_unique_id != ''
 
     @flaky(3, 1)
     @pytest.mark.timeout(10)
@@ -228,7 +253,9 @@ class TestPhoto(object):
 
         assert isinstance(photo, PhotoSize)
         assert isinstance(photo.file_id, str)
+        assert isinstance(photo.file_unique_id, str)
         assert photo.file_id != ''
+        assert photo.file_unique_id != ''
 
     @flaky(3, 1)
     @pytest.mark.timeout(10)
@@ -243,7 +270,9 @@ class TestPhoto(object):
 
         assert isinstance(photo, PhotoSize)
         assert isinstance(photo.file_id, str)
+        assert isinstance(photo.file_unique_id, str)
         assert photo.file_id != ''
+        assert photo.file_unique_id != ''
 
     @flaky(3, 1)
     @pytest.mark.timeout(10)
@@ -266,7 +295,9 @@ class TestPhoto(object):
         message = bot.send_photo(chat_id, photo=raw_bytes)
         photo = message.photo[-1]
         assert isinstance(photo.file_id, str)
+        assert isinstance(photo.file_unique_id, str)
         assert photo.file_id != ''
+        assert photo.file_unique_id != ''
         assert isinstance(photo, PhotoSize)
         assert photo.width == 1280
         assert photo.height == 720
@@ -289,14 +320,18 @@ class TestPhoto(object):
 
         assert isinstance(message.photo[0], PhotoSize)
         assert isinstance(message.photo[0].file_id, str)
+        assert isinstance(message.photo[0].file_unique_id, str)
         assert message.photo[0].file_id != ''
+        assert message.photo[0].file_unique_id != ''
         assert message.photo[0].width == thumb.width
         assert message.photo[0].height == thumb.height
         assert message.photo[0].file_size == thumb.file_size
 
         assert isinstance(message.photo[1], PhotoSize)
         assert isinstance(message.photo[1].file_id, str)
+        assert isinstance(message.photo[1].file_unique_id, str)
         assert message.photo[1].file_id != ''
+        assert message.photo[1].file_unique_id != ''
         assert message.photo[1].width == photo.width
         assert message.photo[1].height == photo.height
         assert message.photo[1].file_size == photo.file_size
@@ -304,6 +339,7 @@ class TestPhoto(object):
     def test_de_json(self, bot, photo):
         json_dict = {
             'file_id': photo.file_id,
+            'file_unique_id': photo.file_unique_id,
             'width': self.width,
             'height': self.height,
             'file_size': self.file_size
@@ -311,6 +347,7 @@ class TestPhoto(object):
         json_photo = PhotoSize.de_json(json_dict, bot)
 
         assert json_photo.file_id == photo.file_id
+        assert json_photo.file_unique_id == photo.file_unique_id
         assert json_photo.width == self.width
         assert json_photo.height == self.height
         assert json_photo.file_size == self.file_size
@@ -320,6 +357,7 @@ class TestPhoto(object):
 
         assert isinstance(photo_dict, dict)
         assert photo_dict['file_id'] == photo.file_id
+        assert photo_dict['file_unique_id'] == photo.file_unique_id
         assert photo_dict['width'] == photo.width
         assert photo_dict['height'] == photo.height
         assert photo_dict['file_size'] == photo.file_size
@@ -348,11 +386,11 @@ class TestPhoto(object):
         assert photo.get_file()
 
     def test_equality(self, photo):
-        a = PhotoSize(photo.file_id, self.width, self.height)
-        b = PhotoSize(photo.file_id, self.width, self.height)
-        c = PhotoSize(photo.file_id, 0, 0)
-        d = PhotoSize('', self.width, self.height)
-        e = Sticker(photo.file_id, self.width, self.height, False)
+        a = PhotoSize(photo.file_id, photo.file_unique_id, self.width, self.height)
+        b = PhotoSize('', photo.file_unique_id, self.width, self.height)
+        c = PhotoSize(photo.file_id, photo.file_unique_id, 0, 0)
+        d = PhotoSize('', '', self.width, self.height)
+        e = Sticker(photo.file_id, photo.file_unique_id, self.width, self.height, False)
 
         assert a == b
         assert hash(a) == hash(b)
