@@ -33,7 +33,7 @@ def successful_payment():
                              order_info=TestSuccessfulPayment.order_info)
 
 
-class TestSuccessfulPayment(object):
+class TestSuccessfulPayment:
     invoice_payload = 'invoice_payload'
     shipping_option_id = 'shipping_option_id'
     currency = 'EUR'
