@@ -29,7 +29,7 @@ except ImportError:
 from telegram import TelegramObject
 
 
-class TestTelegramObject(object):
+class TestTelegramObject:
     def test_to_json_native(self, monkeypatch):
         if ujson:
             monkeypatch.setattr('ujson.dumps', json_lib.dumps)
@@ -74,3 +74,12 @@ class TestTelegramObject(object):
 
         monkeypatch.setattr('telegram.TelegramObject.to_dict', lambda _: d)
         telegram_object.to_json()
+
+    def test_to_dict_private_attribute(self):
+        class TelegramObjectSubclass(TelegramObject):
+            def __init__(self):
+                self.a = 1
+                self._b = 2
+
+        subclass_instance = TelegramObjectSubclass()
+        assert subclass_instance.to_dict() == {'a': 1}
