@@ -20,6 +20,7 @@ import logging
 import os
 import signal
 import sys
+import asyncio
 from flaky import flaky
 from functools import partial
 from queue import Queue
@@ -27,27 +28,48 @@ from random import randrange
 from threading import Thread, Event
 from time import sleep
 
-try:
-    # python2
-    from urllib2 import urlopen, Request, HTTPError
-except ImportError:
-    # python3
-    from urllib.request import Request, urlopen
-    from urllib.error import HTTPError
+from urllib.request import Request, urlopen
+from urllib.error import HTTPError
 
 import pytest
-from future.builtins import bytes
 
 from telegram import TelegramError, Message, User, Chat, Update, Bot
 from telegram.error import Unauthorized, InvalidToken, TimedOut, RetryAfter
-from telegram.ext import Updater, Dispatcher, BasePersistence
+from telegram.ext import Updater, Dispatcher, DictPersistence
 
 signalskip = pytest.mark.skipif(sys.platform == 'win32',
                                 reason='Can\'t send signals without stopping '
                                        'whole process on windows')
 
 
-class TestUpdater(object):
+if sys.platform.startswith("win") and sys.version_info >= (3, 8):
+    """set default asyncio policy to be compatible with tornado
+    Tornado 6 (at least) is not compatible with the default
+    asyncio implementation on Windows
+    Pick the older SelectorEventLoopPolicy on Windows
+    if the known-incompatible default policy is in use.
+    do this as early as possible to make it a low priority and overrideable
+    ref: https://github.com/tornadoweb/tornado/issues/2608
+    TODO: if/when tornado supports the defaults in asyncio,
+            remove and bump tornado requirement for py38
+    Copied from https://github.com/ipython/ipykernel/pull/456/
+    """
+    try:
+        from asyncio import (
+            WindowsProactorEventLoopPolicy,
+            WindowsSelectorEventLoopPolicy,
+        )
+    except ImportError:
+        pass
+        # not affected
+    else:
+        if type(asyncio.get_event_loop_policy()) is WindowsProactorEventLoopPolicy:
+            # WindowsProactorEventLoopPolicy is not compatible with tornado 6
+            # fallback to the pre-3.8 default of Selector
+            asyncio.set_event_loop_policy(WindowsSelectorEventLoopPolicy())
+
+
+class TestUpdater:
     message_count = 0
     received = None
     attempts = 0
@@ -150,7 +172,7 @@ class TestUpdater(object):
         monkeypatch.setattr('telegram.ext.Dispatcher.process_update', lambda _, u: q.put(u))
 
         ip = '127.0.0.1'
-        port = randrange(1024, 49152)  # Select random port for travis
+        port = randrange(1024, 49152)  # Select random port
         updater.start_webhook(
             ip,
             port,
@@ -186,7 +208,7 @@ class TestUpdater(object):
         monkeypatch.setattr(updater.bot, 'set_webhook', lambda *args, **kwargs: True)
         monkeypatch.setattr(updater.bot, 'delete_webhook', lambda *args, **kwargs: True)
         ip = '127.0.0.1'
-        port = randrange(1024, 49152)  # Select random port for travis
+        port = randrange(1024, 49152)  # Select random port
         tg_err = False
         try:
             updater._start_webhook(
@@ -210,7 +232,7 @@ class TestUpdater(object):
         monkeypatch.setattr('telegram.ext.Dispatcher.process_update', lambda _, u: q.put(u))
 
         ip = '127.0.0.1'
-        port = randrange(1024, 49152)  # Select random port for travis
+        port = randrange(1024, 49152)  # Select random port
         updater.start_webhook(ip, port, webhook_url=None)
         sleep(.2)
 
@@ -230,7 +252,7 @@ class TestUpdater(object):
         monkeypatch.setattr('telegram.ext.Dispatcher.process_update', lambda _, u: q.put(u))
 
         ip = '127.0.0.1'
-        port = randrange(1024, 49152)  # Select random port for travis
+        port = randrange(1024, 49152)  # Select random port
         updater.start_webhook(
             ip,
             port,
@@ -246,6 +268,33 @@ class TestUpdater(object):
         assert q.get(False).message.default_quote is True
         updater.stop()
 
+    @pytest.mark.skipif(not (sys.platform.startswith("win") and sys.version_info >= (3, 8)),
+                        reason="only relevant on win with py>=3.8")
+    def test_webhook_tornado_win_py38_workaround(self, updater, monkeypatch):
+        updater._default_quote = True
+        q = Queue()
+        monkeypatch.setattr(updater.bot, 'set_webhook', lambda *args, **kwargs: True)
+        monkeypatch.setattr(updater.bot, 'delete_webhook', lambda *args, **kwargs: True)
+        monkeypatch.setattr('telegram.ext.Dispatcher.process_update', lambda _, u: q.put(u))
+
+        ip = '127.0.0.1'
+        port = randrange(1024, 49152)  # Select random port
+        updater.start_webhook(
+            ip,
+            port,
+            url_path='TOKEN')
+        sleep(.2)
+
+        try:
+            from asyncio import (WindowsSelectorEventLoopPolicy)
+        except ImportError:
+            pass
+            # not affected
+        else:
+            assert isinstance(asyncio.get_event_loop_policy(), WindowsSelectorEventLoopPolicy)
+
+        updater.stop()
+
     @pytest.mark.parametrize(('error',),
                              argvalues=[(TelegramError(''),)],
                              ids=('TelegramError',))
@@ -412,7 +461,7 @@ class TestUpdater(object):
 
     def test_mutual_exclude_persistence_dispatcher(self):
         dispatcher = Dispatcher(None, None)
-        persistence = BasePersistence()
+        persistence = DictPersistence()
         with pytest.raises(ValueError):
             Updater(dispatcher=dispatcher, persistence=persistence)
 
